@@ -1,10 +1,5 @@
 package Dist::Zilla::Plugin::InsertBlock;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-14'; # DATE
-our $DIST = 'Dist-Zilla-Plugin-InsertBlock'; # DIST
-our $VERSION = '0.102'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -17,8 +12,12 @@ with (
     },
 );
 
-use namespace::autoclean;
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-09-16'; # DATE
+our $DIST = 'Dist-Zilla-Plugin-InsertBlock'; # DIST
+our $VERSION = '0.103'; # VERSION
 
+use namespace::autoclean;
 has _directive_re => (is=>'rw', default=>sub{qr/INSERT_BLOCK/});
 
 sub munge_files {
@@ -91,7 +90,7 @@ Dist::Zilla::Plugin::InsertBlock - Insert a block of text from another file
 
 =head1 VERSION
 
-This document describes version 0.102 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2021-04-14.
+This document describes version 0.103 of Dist::Zilla::Plugin::InsertBlock (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2021-09-16.
 
 =head1 SYNOPSIS
 
@@ -165,11 +164,11 @@ In lib/Foo/Bar.pm:
 
 =head1 DESCRIPTION
 
-This plugin finds C<< # INSERT_BLOCK: <file> <name> >> directive in your
-POD/code, find the block of text named I<name> in I<file>, and inserts the block
-of text to replace the directive.
+This plugin finds C<< # INSERT_BLOCK: <file> <name> >> directives in your
+POD/code. It then searches for a block of text named I<name> in file I<file>,
+and inserts the content of the block to replace the directive.
 
-Block is marked/defined using either this syntax:
+A block is marked/defined using either this syntax:
 
  # BEGIN_BLOCK: Name
  ...
@@ -183,8 +182,8 @@ or this (for block inside POD):
 
  =for END_BLOCK: Name
 
-or this syntax (for block inside POD, in case tools like L<Pod::Weaver> removes
-C<=for> directives):
+or this C<=over 11> workaround syntax (for blocks inside POD, in case tools like
+L<Pod::Weaver> remove C<=for> directives):
 
  =over 11
 
@@ -198,8 +197,8 @@ C<=for> directives):
 
 Block name is case-sensitive.
 
-This plugin can be useful to avoid repetition/manual copy-paste, e.g. you want
-to list POD attributes, methods, etc from a base class into a subclass.
+This plugin can be useful to avoid repetition/manual copy-paste, e.g. when you
+want to list POD attributes, methods, etc from a base class into a subclass.
 
 =head2 Options
 
@@ -226,14 +225,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-InsertBlock>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-InsertBlock/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Dist::Zilla::Plugin::InsertBlock::FromModule>
@@ -251,11 +242,36 @@ instead of just a block of text from a file
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-InsertBlock>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
