@@ -1,10 +1,5 @@
 package Dist::Zilla::Plugin::InsertBlock::FromModule;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-04-14'; # DATE
-our $DIST = 'Dist-Zilla-Plugin-InsertBlock'; # DIST
-our $VERSION = '0.102'; # VERSION
-
 use 5.010001;
 use strict;
 use warnings;
@@ -13,6 +8,11 @@ use Module::Path::More qw(module_path);
 
 use parent qw(Dist::Zilla::Plugin::InsertBlock);
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-09-16'; # DATE
+our $DIST = 'Dist-Zilla-Plugin-InsertBlock'; # DIST
+our $VERSION = '0.103'; # VERSION
+
 sub BUILD {
     my $self = shift;
 
@@ -51,7 +51,7 @@ Dist::Zilla::Plugin::InsertBlock::FromModule - Insert a block of text from anoth
 
 =head1 VERSION
 
-This document describes version 0.102 of Dist::Zilla::Plugin::InsertBlock::FromModule (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2021-04-14.
+This document describes version 0.103 of Dist::Zilla::Plugin::InsertBlock::FromModule (from Perl distribution Dist-Zilla-Plugin-InsertBlock), released on 2021-09-16.
 
 =head1 SYNOPSIS
 
@@ -118,14 +118,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/Dist-Zilla
 
 Source repository is at L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-InsertBlock>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Dist-Zilla-Plugin-InsertBlock/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<Dist::Zilla::Plugin::InsertBlock>
@@ -134,11 +126,36 @@ L<Dist::Zilla::Plugin::InsertBlock>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2016, 2015 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2016, 2015 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Dist-Zilla-Plugin-InsertBlock>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
